@@ -46,7 +46,13 @@ sub _kill_child {
 
 sub valid_file {
     my($self, $file) = @_;
-    $file->{path} !~ m!\.(?:git|svn)[/\\]|\.(?:bak|swp)$|~$|_flymake\.p[lm]!;
+
+    # vim temporary file is  4913 to 5036
+    # http://www.mail-archive.com/vim_dev@googlegroups.com/msg07518.html
+    if ( $file->{path} =~ m{(\d+)$} && $1 >= 4913 && $1 <= 5036) {
+        return 0;
+    }
+    $file->{path} !~ m!\.(?:git|svn)[/\\]|\.(?:bak|swp|swpx|swx)$|~$|_flymake\.p[lm]$!;
 }
 
 sub run {
